summaryrefslogtreecommitdiff
path: root/libre/reflector/9001-branding.patch
blob: 56ea17fc80ccf3a654ff8a00b652258839057d25 (plain)
1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
19
20
21
22
23
24
25
26
27
28
29
30
31
32
33
34
35
36
37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
diff --git a/man/reflector.1 b/man/reflector.1
index bd818cc..a543e02 100644
--- a/man/reflector.1
+++ b/man/reflector.1
@@ -11,8 +11,8 @@ reflector - retrieve and filter the latest Pacman mirrorlist
 .SH DESCRIPTION
 .PP
 reflector is a Python script and associated Python module that can
-retrieve up-to-date Arch Linux mirror data from the Mirror
-Status (https://www.archlinux.org/mirrors/status/) web interface.
+retrieve up-to-date Parabola GNU/Linux-libre mirror data from the
+Mirror Status (https://www.parabola.nu/mirrors/status/) web interface.
 .SH ARGUMENTS
 .PP
 See \f[C]reflector --help\f[R].
diff --git a/Reflector.py b/Reflector.py
index 532484f..f3f1948 100644
--- a/Reflector.py
+++ b/Reflector.py
@@ -21,7 +21,7 @@
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 
 '''
-Retrieve Arch Linux mirrors.
+Retrieve Parabola GNU/Linux-libre mirrors.
 '''
 
 import argparse
@@ -50,7 +50,7 @@ import urllib.request
 
 NAME = 'Reflector'
 
-URL = 'https://archlinux.org/mirrors/status/json/'
+URL = 'https://www.parabola.nu/mirrors/status/json/'
 
 DISPLAY_TIME_FORMAT = '%Y-%m-%d %H:%M:%S UTC'
 PARSE_TIME_FORMAT = '%Y-%m-%dT%H:%M:%SZ'
@@ -598,7 +598,7 @@ def format_mirrorlist(
 
     width = 80
     colw = 11
-    header = '# Arch Linux mirrorlist generated by Reflector #'.center(width, '#')
+    header = '# Parabola GNU/Linux-libre mirrorlist generated by Reflector #'.center(width, '#')
     border = '#' * len(header)
     mirrorlist = f'{border}\n{header}\n{border}\n\n' + \
         '\n'.join(
@@ -653,8 +653,18 @@ class MirrorStatus():
         'extra',
         'gnome-unstable',
         'kde-unstable',
+        'libre',
+        'libre-testing',
+        'libre-multilib',
+        'libre-multilib-testing',
         'multilib',
-        'multilib-testing'
+        'multilib-testing',
+        'nonprism',
+        'nonprism-testing',
+        'pcr',
+        'kernels',
+        'java',
+        'cross',
         'staging',
         'testing'
     )
@@ -828,8 +838,8 @@ def add_arguments(parser):
     parser.add_argument(
         '--cache-timeout', type=int, metavar='n', default=DEFAULT_CACHE_TIMEOUT,
         help=(
-            '''The cache timeout in seconds for the data retrieved from the Arch
-            Linux Mirror Status API. The default is %(default)s. '''
+            '''The cache timeout in seconds for the data retrieved from the Parabola
+            GNU/Linux-libre Mirror Status API. The default is %(default)s. '''
         )
     )
 
@@ -1013,7 +1023,7 @@ def parse_args(args=None):
     Parse command-line arguments.
     '''
     parser = MyArgumentParser(
-        description='retrieve and filter a list of the latest Arch Linux mirrors',
+        description='retrieve and filter a list of the latest Parabola GNU/Linux-libre mirrors',
         fromfile_prefix_chars='@'
     )
     parser = add_arguments(parser)